# http://www.python.org/dev/peps/pep-0396/
__version__ = '5.1.0'
# another variable is required to prevent semantic release from updating version in more than one place
main_version = __version__
# backward compatibility
# for beta versions, integer casting throws an exception, so string part must be cut off
if 'beta' in __version__:
    main_version = __version__.split('-beta')[0]
version = tuple(int(x) for x in main_version.split('.'))
majorVersionId = version[0]
